﻿using InstanceFactory.MimicAppConfig.Common;
using InstanceFactory.MimicAppConfig.Configuration;
using Windows.UI.Xaml;

namespace InstanceFactory.MimicAppConfig.SettingsPages
{
  /// <summary>
  /// Page to setup the app.config to use.
  /// </summary>
  public sealed partial class AppConfigSettingsPage : SettingsPageBase
  {
    #region Public Constructors

    /// <summary>
    /// Initializes a new instance of <see cref="AppConfigSettingsPage"/>
    /// </summary>
    public AppConfigSettingsPage()
    {
      this.InitializeComponent();

      // Set the data context
      DataContext = AppConfiguration.Current;

      // Now set the Toggled-Handler to avoid unnessesary event handling when control is initialized.
      AppConfigToggleSwitch.Toggled += OnSettingsChanged;
    }

    #endregion Public Constructors


    #region Private Methods

    /// <summary>
    /// Invoked when "On/Off" state of the app.config selection switch changed.
    /// </summary>
    /// <param name="sender">Sender of the event.</param>
    /// <param name="args">Event arguments.</param>
    private void OnSettingsChanged
      (
      object sender,
      RoutedEventArgs args
      )
    {
      // Just save the config values. The values are set properly already by using two-way data binding.
      AppConfiguration.Current.Save();
    }

    #endregion Private Methods
  }
}
